OC.L10N.register(
    "notes",
    {
    "Notes" : "Notas",
    "New note" : "Nove nota",
    "Delete note" : "Dele nota",
    "_%n word_::_%n words_" : ["%n parola","%n parolas"]
},
"nplurals=2; plural=(n != 1);");
